@@ -1,12 +1,16 @@
 use std::fmt;
+use std::num;
 
+use nom;
 use chrono;
 
-#[derive(Debug)]
+#[derive(Debug, PartialEq)]
 pub enum Error {
   NoSuchCommand(String),
   MissingArgument(String),
   ParseTimeError(chrono::format::ParseError),
+  ParseDurationError,
+  ParseIntError(num::ParseIntError),
   DurationRoundingError(chrono::RoundingError),
 }
 
@@ -16,6 +20,18 @@ impl From<chrono::format::ParseError> for Error {
   }
 }
 
+impl<E> From<nom::Err<E>> for Error {
+  fn from(_: nom::Err<E>) -> Self {
+    Self::ParseDurationError
+  }
+}
+
+impl From<std::num::ParseIntError> for Error {
+  fn from(error: std::num::ParseIntError) -> Self {
+    Self::ParseIntError(error)
+  }
+}
+
 impl From<chrono::RoundingError> for Error {
   fn from(error: chrono::RoundingError) -> Self {
     Self::DurationRoundingError(error)
@@ -28,6 +44,8 @@ impl fmt::Display for Error {
       Self::NoSuchCommand(msg) => write!(f, "No such command: {}", msg),
       Self::MissingArgument(msg) => write!(f, "Missing argument: {}", msg),
       Self::ParseTimeError(err) => err.fmt(f),
+      Self::ParseDurationError => write!(f, "Invalid duration"),
+      Self::ParseIntError(err) => err.fmt(f),
       Self::DurationRoundingError(err) => err.fmt(f),
     }
   }
